A collection of Rust crates.
Do not use this project. It is neither stable nor supported.
This crate provides brief documentation and examples of selected high-quality Rust crates suitable for a variety of Rust programs. It can be read as reference documentation or imported through a Cargo dependency as a “batteries included” supercrate.
To use rustmax as a crate dependency,
read the documentation in the guide module.
Modules
- ahash
- A fast and DOS-resistent hash function, for use in
HashMaps. - alloc
- The Rust core allocation and collections library
- anyhow
- Flexible error handling.
- axum
- Web application framework built on
tokioandhyper. - base64
- Base64 encoding and decoding.
- bindgen
- Generate Rust bindings to C and C++ libraries.
- bitflags
- Types in which the bits are individually addressable.
- blake3
- The BLAKE3 cryptographic hash function.
- bytes
- Efficient byte buffer management.
- cc
- A basic cross-platform C compiler driver.
- cfg_if
- Compile-time conditional compilation as
if/elseblocks. - chrono
- Date and time library.
- clap
- Command line argument parsing.
- comrak
- CommonMark and GitHub Flavored Markdown parser.
- core
- The Rust Core Library
- crossbeam
- Concurrency tools to supplement
std::sync, including fast channels. - ctrlc
- Simple handling of Ctrl+C for CLI programs.
- cxx
- C++ bridge runtime support; paired with
cxx_build. - cxx_
build - C++ bridge generator; paired with
cxx. - derive_
more - Derive implementations for common traits.
- env_
logger - A simple logger that can be configured via environment variables.
- extension_
trait - A macro for defining extension methods on external types.
- extras
- Additional tidbits defined by
rmx. - flate2
- Deflate, gzip, and zlib compression.
- futures
- Async programming primitives and utilities.
- glob
- Unix shell style pattern matching.
- guide
- A Guide to the Rustmax crate.
- hex
- Hexadecimal encoding and decoding.
- http
- Shared type definitions for the HTTP protocol.
- hyper
- Low-level HTTP/1 and HTTP/2 implementation for the
tokioecosystem. - ignore
- Fast directory traversal respecting gitignore rules.
- image
- Image processing and manipulation.
- indicatif
- Progress bars and spinners for CLI applications.
- itertools
- Extra iterator methods and utilities.
- jiff
- Modern date and time library.
- json5
- JSON5 parsing and serialization.
- libc
- Raw FFI bindings to platform-specific system libraries.
- log
- A lightweight logging facade for Rust.
- memchr
- Fast byte search primitives with SIMD acceleration.
- mime
- MIME type parsing and manipulation.
- nom
- Parser combinator library for building zero-copy parsers.
- notify
- Cross-platform filesystem notification library.
- num_
bigint - Arbitrary precision integers.
- num_
enum - Type-safe conversions between enums and primitive numbers.
- powerletters
- Concise single-letter methods for common operations.
- prelude
- The
rmxprelude. - proc_
macro - A support library for macro authors when defining new macros.
- proc_
macro2 - A preferred wrapper around the standard
proc_macrocrate. - proptest
- Property-based testing framework for Rust.
- quote
- Quasi-quoting for generating Rust source code as tokens.
- rand
- Random number generation.
- rand_
chacha - ChaCha-based cryptographically secure random number generators.
- rand_
pcg - PCG family of fast, non-cryptographic random number generators.
- rayon
- Data parallelism library for Rust.
- regex
- Regular expression engine with support for Unicode.
- reqwest
- HTTP client for making web requests.
- rustyline
- Interactive line editor for CLI applications.
- semver
- Semantic version parsing and comparison.
- serde
- Serialization and deserialization framework.
- serde_
json - JSON serialization and deserialization.
- sha2
- The SHA-2 cryptographic hash functions.
- socket2
- Low-level network socket programming beyond
std::net. - std
- The Rust Standard Library
- syn
- A Rust parser used by procedural macros.
- tempfile
- Temporary files and directories with automatic cleanup.
- tera
- Text template engine based on Jinja2/Django.
- termcolor
- Cross-platform terminal colors.
- thiserror
- Tools for defining custom error types.
- tokio
- Asynchronous runtime for writing reliable network applications.
- toml
- TOML parsing and serialization.
- tower
- Modular middleware framework for async request/response services.
- unicode_
segmentation - Splitting strings on grapheme cluster, word, and sentence boundaries.
- url
- URL parsing and manipulation.
- walkdir
- Efficient directory traversal.
- xshell
- Shell-like scripting in Rust without invoking a shell.
- zip
- Read and write ZIP archives.
Macros
- bug
- Like ‘unimplemented’ but shorter to type.